interface ActivatedBy {
    comparison?: {
        message: string;
        messageClassification: string;
        messageDisplayType: string;
        Key: string;
        Type: string;
        LuggageSource: string;
        Operator: string;
    };
    Key: string;
    Type?: string;
    LuggageSource?: string;
    Operator?: string;
    Values?: string[];
    ActivatedBy?: ActivatedBy[];
}
interface Validation {
    comparison?: {
        message: string;
        messageClassification: string;
        messageDisplayType: string;
        Key: string;
        Type: string;
        LuggageSource: string;
        Operator: string;
    };
    min?: {
        value: string;
        error: string;
    };
    max?: {
        value: string;
        error: string;
    };
    pattern?: {
        value: string;
        error: string;
    };
}
interface PrePopulate {
    PrePopulatedBy: {
        Key: string;
        Type: string;
        LuggageSource?: string;
    };
}
interface Photos {
    Label: string;
    Min?: number;
    Max?: number;
    Visible?: string;
    ActivatedBy?: ActivatedBy[];
    [key: string]: any;
}
interface Videos {
    Label: string;
    Min?: number;
    MaxDuration?: number;
    Visible?: string;
    ActivatedBy?: ActivatedBy[];
    [key: string]: any;
}
interface Documents {
    Label: string;
    Min?: number;
    Max?: number;
    Visible?: string;
    ActivatedBy?: ActivatedBy[];
    [key: string]: any;
}
interface ScreenShots {
    Label: string;
    Min?: number;
    Max?: number;
    Visible?: string;
    ActivatedBy?: ActivatedBy[];
    [key: string]: any;
}
interface Media {
    Photos?: Photos[];
    Videos?: Videos[];
    Documents?: Documents[];
    ScreenShots?: ScreenShots[];
}
interface Answers {
    Key: string;
    Sort: number;
    Visible?: string;
    Terminal?: string;
    Default?: string;
    Media?: Media;
    ActivatedBy?: ActivatedBy[];
    [key: string]: any;
}
interface Questions {
    Name: string;
    Sort: number;
    ReadOnly?: string;
    Required?: string;
    Hidden?: string;
    Visible?: string;
    Type: string;
    Validation?: Validation;
    PrePopulate?: PrePopulate;
    ActivatedBy?: ActivatedBy[];
    Answers?: Answers[];
    [key: string]: any;
}
interface QuestionGroups {
    Type: string;
    Name: string;
    DisplayQuestionGroupName?: string;
    Sort: number;
    Hidden?: string;
    Required?: string;
    Visible: string;
    ActivatedBy?: ActivatedBy[];
    Questions: Questions[];
    [key: string]: any;
}
interface Stations {
    Type: string;
    Name: string;
    GroupName?: string;
    Hidden?: string;
    Visible: string;
    ActivatedBy?: ActivatedBy[];
    QuestionGroups: QuestionGroups[];
    [key: string]: any;
}
interface ScriptProps {
    Name: string;
    Stations: Stations[];
}
interface StationProps extends Stations {
}
interface StationArrayProps {
    Type: string;
    Name: string;
    GroupName?: string;
    Hidden: string;
    Visible: string;
    ActivatedBy?: ActivatedBy[];
}
interface QusetionsProps {
    [key: string]: {
        StationName: string;
        QuestionGroup: string;
        UserResponse: any;
        error: string;
    };
}
interface QuestionProps extends Questions {
    QuestionGroupName?: string;
    StationName?: string;
    userResponse?: any;
    Dynamic?: {
        Methode: string;
        Parameters?: {
            Name: string;
            Value: string;
            Type: string;
        }[];
    };
}
interface ActivatedByProps extends ActivatedBy {
}
interface AnswerProps extends Answers {
}
interface QuestionGroupProps {
    Type: string;
    Name: string;
    DisplayQuestionGroupName?: string;
    Sort?: number;
    Hidden?: string;
    Required?: string;
    Visible: string;
    ActivatedBy?: ActivatedBy[];
    [key: string]: any;
    Questions: {
        Name: string;
        Transport?: string;
        Sort: number;
        Type: string;
        Required?: string;
        Hidden?: string;
        Visible?: string;
        Validation?: Validation;
        PrePopulate?: PrePopulate;
        QuestionGroupName?: string;
        StationName?: string;
        userResponse?: any;
        Dynamic?: {
            Methode: string;
            Parameters?: {
                Name: string;
                Value: string;
                Type: string;
            }[];
        };
        Answers?: Answers[];
    }[];
}
interface LanguageProps {
    language: string;
    generatedDate: string;
    keyValues: {
        [key: string]: string;
    };
}
interface LuggageProps {
    scriptHash: string;
    Luggages: {
        [key: string]: {
            [key: string]: {
                [key: string]: {
                    key: string;
                    answers?: string[];
                    media?: {
                        imageId: string[];
                        label: string;
                        mediaType: string;
                    }[];
                };
            };
        };
    };
}
interface RenderStationProps {
    Type: string;
    Name: string;
    GroupName?: string;
    Hidden: string;
    Visible: string;
    ActivatedBy?: ActivatedBy[];
}
interface GetScriptApiResponse {
    scriptHash: string;
    scriptValueGzip: string;
}
interface CompressDataProps {
    id: string;
    imageType: number;
    fileName: string;
    orderNumber: number;
    userName: string;
}
interface GetUplodUrlProps {
    id: string;
    imageType: number;
    fileName: string;
    orderNumber: number;
    userName: string;
}
interface UploadImgProps {
    id: string;
    imageType: number;
    fileName: string;
    orderNumber: number;
    userName: string;
    url: string;
    file: any;
    metaData?: string;
    config: any;
}
interface GetMediaStatus {
    id: string;
    orderNumber: string;
}
export type { ScriptProps, StationProps, StationArrayProps, QusetionsProps, QuestionProps, ActivatedByProps, AnswerProps, QuestionGroupProps, LanguageProps, LuggageProps, RenderStationProps, GetScriptApiResponse, CompressDataProps, GetUplodUrlProps, UploadImgProps, GetMediaStatus, Photos, Videos, Documents, ScreenShots, };
